@@ -1,10 +1,10 @@
 Adjust the texmfcnf.lua file to realities in Debian
 ---
- texmf-dist/web2c/texmfcnf.lua |   26 ++++++++++++--------------
- 1 file changed, 12 insertions(+), 14 deletions(-)
+ texmf-dist/web2c/texmfcnf.lua |   27 ++++++++++++---------------
+ 1 file changed, 12 insertions(+), 15 deletions(-)
 
---- texlive-base-2020.20200313.orig/texmf-dist/web2c/texmfcnf.lua
-+++ texlive-base-2020.20200313/texmf-dist/web2c/texmfcnf.lua
+--- a/texmf-dist/web2c/texmfcnf.lua
++++ b/texmf-dist/web2c/texmfcnf.lua
 @@ -3,17 +3,15 @@
  -- ConTeXt needs a properly expanded TEXMFLOCAL, so here is a
  -- bit of lua code to make that happen
@@ -25,16 +25,17 @@ Adjust the texmfcnf.lua file to realities in Debian
  
      content = {
  
-@@ -44,7 +42,7 @@ return {
+@@ -43,8 +41,7 @@ return {
+             -- }
  
              -- only used for FONTCONFIG_PATH & TEXMFCACHE in TeX Live
- 
+-
 -            TEXMFSYSVAR     = "selfautoparent:texmf-var",
 +            TEXMFSYSVAR     = "/var/lib/texmf",
-             TEXMFVAR        = "home:.texlive2020/texmf-var",
+             TEXMFVAR        = "home:.texlive2021/texmf-var",
  
              -- We have only one cache path but there can be more. The first writable one
-@@ -61,13 +59,13 @@ return {
+@@ -61,13 +58,13 @@ return {
              -- By using prefixes we don't get expanded paths in the cache __path__
              -- entry. This makes the tex root relocatable.
  
@@ -55,7 +56,7 @@ Adjust the texmfcnf.lua file to realities in Debian
  
              TEXMFHOME       = "home:texmf",
           -- TEXMFHOME       = os.name == "macosx" and "home:Library/texmf" or "home:texmf",
-@@ -75,7 +73,7 @@ return {
+@@ -75,7 +72,7 @@ return {
              -- We need texmfos for a few rare files but as I have a few more bin trees
              -- a hack is needed. Maybe other users also have texmf-platform-new trees.
  
@@ -64,7 +65,7 @@ Adjust the texmfcnf.lua file to realities in Debian
  
              TEXFONTMAPS     = ".;$TEXMF/fonts/data//;$TEXMF/fonts/map/{pdftex,dvips}//",
              ENCFONTS        = ".;$TEXMF/fonts/data//;$TEXMF/fonts/enc/{dvips,pdftex}//",
-@@ -174,7 +172,7 @@ return {
+@@ -174,7 +171,7 @@ return {
              -- In an edit cycle it can be handy to launch an editor. The
              -- preferred one can be set here.
  
